% La fonction "brownien1D" simule et trace une trajectoire de mouvement
% brownien unidimensionnel (avec sigma^2 = 2) sur l'intervalle [0,10].
function brownien1D
% "sigma2" est la variance par unité de temps ; ici 2.
sigma2 = 2;
% "tmax" est la longueur de l'intervalle de simulation, ici 10.
tmax = 10;
% "N" est le nombre de pas de temps en lequel on subdivise l'intervalle
% [0,tmax] pour la discrétisation, ici choisi à 2000.
N = 2000;
% "epsilon" est la largeur d'un pas de discrétisation (on prend ici des pas
% de même taille).
epsilon = tmax / N;
% "T" est la liste des temps auxquels on discrétise.
T = epsilon * (0:N);
% "B" est destiné à contenir la liste des valeurs du mouvement brownien aux
% différents temps de "T".
B = zeros(1,N+1);
% Le mouvement brownien part de 0; on entre donc cette valeur initiale.
B(1) = 0;
% Cette boucle correspond à la méthode d'Euler stochastique. "i" est
% l'indice du dernier point simulé dans la liste "B".
for i = 1:N
    % On incrémente le mouvement brownien. L'incrément est indépendant du
    % passé, de loi N(sigma^2*epsilon).
    B(i+1) = B(i) + sqrt(sigma2 * epsilon) * randn;
end
% On trace la courbe du mouvement brownien.
plot(T,B,'LineWidth',2);
title('Mouvement brownien 1D (sigma^2 = 2)');
% Le programme s'arrête.
return
end