% La fonction "brownien2D" simule et trace une trajectoire d'un mouvement
% brownien 2-dimensionnel sur l'intervalle de temps [0,4].
function brownien2D
% "sigmasigmaT" est la matrice de covariance par unité de temps, que je
% choisis ici non standard.
sigmasigmaT = [1,.5;.5,1];
% "sigma" est (la transposée de) la matrice de Cholesky associée à
% "sigmasigmaT", qui nous servira dans la suite pour les simulations.
sigma = chol(sigmasigmaT)';
% "tmax" est la longueur de l'intervalle de simulation, ici 4.
tmax = 4;
% "N" est le nombre de pas de temps en lequel on subdivise l'intervalle
% [0,tmax] pour la discrétisation, ici choisi à 40000.
N = 40000;
% "epsilon" est la largeur d'un pas de discrétisation (on prend ici des pas
% de même taille).
epsilon = tmax / N;
% "B" est destiné à contenir la liste des valeurs du mouvement brownien aux
% différents temps de discrétisation. Chaque colonne de "B" correspondra
% aux 2 coordonnées du mouvement brownien à un certain temps de
% discrétisation.
B = zeros(2,N+1);
% Le mouvement brownien part de (0,0); on entre donc cette valeur initiale.
B(:,1) = [0;0];
% Cette boucle correspond à la méthode d'Euler stochastique. "i" est
% l'indice du dernier point simulé dans la liste "B".
for i = 1:N
    % On incrémente le mouvement brownien. L'incrément est indépendant du
    % passé, de loi N(epsilon*sigmasigmaT).
    B(:,i+1) = B(:,i) + sqrt(epsilon) * sigma * randn(2,1);
end
% On trace la trajectoire du mouvement brownien.
plot(B(1,:),B(2,:),'LineWidth',2);
axis equal;
title('Trajectoire d''un mouvement brownien 2D anisotrope');
% Le programme s'arrête.
return
end