% La fonction "browngeom" simule et trace une trajectoire de mouvement
% brownien géométrique avec sigma^2=1 et b=-1/4, sur l'intervalle de temps
% [0,12]. Le programme s'appuie exactement sur la même structure que
% "brown1D"; seuls la nomenclature, les paramètres et la formule
% d'incrémentation changent.
function browngeom
sigma2 = 1;
% "b" est le paramètre de dérive du mouvement brownien arithmétique
% sous-jacent.
b = -1/4;
tmax = 8;
N = 3000;
epsilon = tmax / N;
T = epsilon * (0:N);
X = zeros(1,N+1);
% Évidemment le mouvement brownien géométrique ne peut pas partir de 0 !
% Ici je choisis de le faire partir de 1.
X(1) = 1;
for i = 1:N
    % Cette fois-ci, l'incrément est de loi N((sigma*X)^2*epsilon) +
    % (b+sigma^2/2)*X*epsilon.
    X(i+1) = X(i) + sqrt(sigma2) * X(i) * sqrt(epsilon) * randn +  ...
        (b + sigma2 / 2) * X(i) * epsilon;
end
plot(T,X,'LineWidth',2);
set(gca,'Ylim',[0,Inf]);
title('Mouvement brownien géométrique (sigma^2=1, b=-1/4)');
return
end