% "maxmarche_ctrl0" effectue le même travail que "maxmarche_spl", mais en
% utilisant la variable de contrôle Y. Je ne commente que les différences
% avec "maxmarche_spl".
function maxmarche_ctrl0(N)
% Attention : cette fois-ci les variables "S" et "S2" ne se réfèreront pas
% à la simulation de "Xmax", mais à celle de Xmax-Y, où "Y" est la variable
% de contrôle.
S = 0;
S2 = 0;
for i = 1:N
    X = cumsum(randn(1,60));
    Xmax = max([0,X]);
    % On calcule la variable de contrôle.
    Y = max(0,X(60));
    % La quantité à laquelle on va appliquer la méthode de Monte-Carlo à
    % proprement parler est la différence Xmax-Y, notée "Z".
    Z = Xmax - Y;
    % On met à jour "S" et "S2".
    S = S + Z;
    S2 = S2 + Z * Z;
end
% On évalue l'estimeur et la marge d'erreur pour E(Z).
mZ = S / N;
sigma = sqrt(S2 / N - mZ * mZ);
erreur = 2 * sigma / sqrt(N);
% On en déduit l'estimateur pour E(Xmax) = E(Z) + E(Y), sachant qu'on sait
% calculer exactement E(Y), appelée ici "EY". Noter que l'addition de EY ne
% modifie pas la marge d'erreur.
EY = sqrt(60 / (2 * pi));
m = mZ + EY;
disp(['E(X_*) : ',num2str(m),' ± ',num2str(erreur)]);
return
end