% La fonction "maxmarche_spl" évalue par la méthode de Monte-Carlo
% l'espérance du maximum d'une marche de 60 pas sur R issue de 0
% d'incréments N(1), sans utiliser de technique de réduction de variance
% particulière. "N" est le nombre de simulations demandées.
function maxmarche_spl(N)
% "S" et "S2" contiendront respectivement la somme des résultats simulés et
% la somme de leurs carrés.
S = 0;
S2 = 0;
for i = 1:N
    % On simule la trajectoire, représentée par le 60-vecteur "X".
    % (Attention, "X" n'inclut pas le point X_0 = 0).
    X = cumsum(randn(1,60));
    % On regarde le maximum de la trajectoire (en incluant X_0), appelé
    % "Xmax".
    Xmax = max([0,X]);
    % On met à jour S et S2.
    S = S + Xmax;
    S2 = S2 + Xmax * Xmax;
end
% "m" est l'estimateur de Monte-Carlo.
m = S / N;
% "sigma" est la variance (estimée) de X_*.
sigma = sqrt(S2 / N - m * m);
% "erreur" est le rayon de l'intervalle de confiance à 2 sigmas.
erreur = 2 * sigma / sqrt(N);
% On affiche le résultat.
disp(['E(X_*) : ',num2str(m),' ± ',num2str(erreur)]);
% Le programme s'arrête.
return
end
