%% Fonction principale
% La fonction "qvgdp" évalue par la méthode de Monte-Carlo le gain moyen
% d'un participant du jeu « Qui veut gagner du pognon ? ».
function qvgdp
% "N" note le nombre de simulations effectuées, ici 10000.
N = 5000;
% "S" stockera la somme des résultats obtenus en vue d'en calculer la
% moyenne.
S = 0;
% On lance la boucle de la méthode de Monte-Carlo, indexée par "i".
for i=1:N,
    % On simule les gains du joueur. Cela est assuré par la sous-routine
    % "pognon" (voir plus loin), qui renvoie le montant gagné.
    gains = pognon;
    % On ajoute les gains de la simulation à la somme "S".
    S = S + gains;
end
% On calcule l'estimateur "m" de l'espérance de gain.
m = S / N;
% On affiche le résultat.
disp(['Estimateur de l''espérance de gain : ',num2str(m),' €']);
% Le programme s'arrête.
return

%% Sous-routine "pognon"
% Cette fonction simule les gains d'un joueur à « Qui veut gagner du pognon
% ? ». Elle renvoie le montant de ces gains (en euros).
function gains = pognon
% "J" est le nombre de jokers restant au joueur.
J = 2;
% "gains" est le montant des gains obtenus par le joueur. Comme les
% paramètres du jeu assurent que le candidat répond toujours correctement à
% la première question (sans dépenser de joker), on intialise directement
% "gains" à 1000.
gains = 1000;
% On passe donc directement à la deuxième question.
k = 2;
% Cette boucle représente le joueur tentant de progresser dans l'échelle
% des questions, jusqu'à son élimination, qui correspond dans ce code à ce
% que "J" devienne négatif.
while J >= 0,
    % "jesais" vaut 1 si la candidat connait la réponse, et 0 s'il
    % l'ignore.
    jesais = (rand < 3 / (k + 2));
    % On regarde si le candidat connait ou non la réponse.
    if jesais
        % Si la candidat connait la réponse, on double ses gains et on
        % passe à la question suivante.
        gains = 2 * gains;
        k = k + 1;
    else
        % Si le candidat ignore la réponse, il est obligé de consommer un
        % joker et de prendre une autre question. S'il n'avait plus de
        % jokers à ce moment-là, "J" devient négatif et on sort de la
        % boucle.
        J = J - 1;
    end
end
% La fonction retourne "gains".
return
