% La fonction "risque_pref" améliore "risque_spl" en échantillonnant selon
% la loi Q. L'interface avec l'utilisateur est la même que pour
% "risque_spl" ; je ne commente que les différences par rapport au
% programme naïf.
function risque_pref(N)
% Cette fois-ci on ne se contente plus de compter les occurrences d'une
% indicatrice ; on a donc besoin de comptabiliser séparément la somme "S"
% et la somme des carrés "S2" de la quantité simulée.
S = 0;
S2 = 0;
C = [1,.2,.3;.2,1,.4;.3,.4,1];
R = chol(C);
% "M" est le vecteur-ligne qui intervient dans l'expression de la loi P;
% "invC" est l'inverse de la matrice "C". Ces deux quantités seront utiles
% par la suite.
M = [-3,-4,-5];
invC = eye(3) / C;
% Le scalaire "facteur" et le vecteur-colonne "coefficients" interviendront
% dans le calcul de la densité de P par rapport à Q, ce qui fait qu'il vaut
% mieux les calculer une fois pour toutes.
facteur = exp(-M * invC * M' / 2);
coefficients = invC * M';
for i = 1:N
    % Le 3-vecteur XYZ est une simulation du triplet (X,Y,Z) /sous la loi
    % Q/.
    XYZ = randn(1,3) * R;
    % "densite" est la densité de P par rapport à Q au point XYZ, calculée
    % d'après notre formule théorique.
    densite = facteur * exp(XYZ * coefficients);
    % "resultat_brut" est l'indicatrice de l'occurrence d'un accident.
    resultat_brut = all(XYZ > 0);
    % Il faut ponderer "resultat_brut" pour tenir compte qu'on
    % échantillonne sous Q; on appelle "resultat" de résultat pondéré par
    % dP/dQ.
    resultat = resultat_brut * densite;
    % On met à jour "S" et "S2".
    S = S + resultat;
    S2 = S2 + resultat * resultat;
end
% Il ne reste plus qu'à calculer, de façon tout-à-fait ordinaire,
% l'estimateur et la marge d'erreur de l'espérance de "resultat" sous Q.
p = S / N;
sigma = sqrt(S2 / N - p * p);
erreur = 2 * sigma / sqrt(N);
disp(['Probabilité d''accident : ',num2str(p),' ± ',num2str(erreur)]);
return
end