% La fonction "risque_spl" évalue la probabilité quotidienne que survienne
% un accident, par une méthode de Monte-Carlo “naïve”. "N" est le nombre de
% simulations demandées.
function risque_spl(N)
% "accidents" comptera le nombre d'accidents sur les N simulations.
accidents = 0;
% "C" est la matrice de covariance des facteurs de risque (X,Y,Z).
C = [1,.2,.3;.2,1,.4;.3,.4,1];
% "R" est une matrice telle que R'R=C, dont nous aurons à nous servir pour
% appliquer la méthode de Cholesky à chaque simulation.
R = chol(C);
% On lance la boucle de simulation.
for i = 1:N
    % Le 3-vecteur XYZ est une simulation du triplet (X,Y,Z), effectuée par
    % la méthode de Cholesky.
    XYZ = [-1,-2,-3] + randn(1,3) * R;
    % "resultat" vaut 1 si les trois composantes de XYZ sont positives et
    % qu'il y a donc accident, et 0 sinon.
    resultat = all(XYZ > 0);
    % On met à jour le compteur "accidents".
    accidents = accidents + resultat;
end
% "p" est la probabilité empirique d'accidents.
p = accidents / N;
% "sigma" est la variance empirique de l'indicatrice d'un accident, qui
% s'exprime directement en fonction de p.
sigma = sqrt(p - p * p);
% "erreur" est la marge d'erreur à 2 sigmas.
erreur = 2 * sigma / sqrt(N);
% On affiche le résultat.
disp(['Probabilité d''accident : ',num2str(p),' ± ',num2str(erreur)]);
% Le programme s'arrête.
return
end