% "rugby_spl" calcule la probabilité de victoire de l'équipe B lorsque
% celle-ci suit la stratégie S_q. La fonction prend en entrée la valeur "q"
% du paramètre de la stratégie.
function rugby_spl(q)
% "N" est le nombre de simulations, fixé à 15 000.
N = 15000;
% "n" contiendra le nombre de simulations où l'équipe B a gagné.
n = 0;
% Ici commence la boucle de simulation.
for i = 1:N
    % "Balavatange", "Bcherchelessai" et "Binscritlessai" sont trois
    % 12-vecteurs disant, pour chaque séquence de jeu, si l'équipe B prend
    % l'avantage lors de cette séquence, puis, *sous réserve qu'elle ait
    % pris l'avantage*, si elle cherche l'essai, puis *sous réserve qu'elle
    % ait pris l'avantage et chercher l'essai*, si elle marque l'essai.
    Balavantage = (rand(1,12) < .4);
    Bcherchelessai = (rand(1,12) < q);
    Binscritlessai = (rand(1,12) < .35);
    % On calcule le score "scoreB" de l'équipe B en fonction des trois
    % 12-vecteurs simulés ci-dessus.
    scoreB = sum(Balavantage .* (7 * Bcherchelessai .* Binscritlessai +...
        3 * (1 - Bcherchelessai)));
    % "scoreA" est le score de l'équipe A. (Il suffit pour simuler ce score
    % de compter les séquences où A prend l'avantage, vu qu'elle choisit
    % systématiquement de prendre le but).
    scoreA = 3 * sum(rand(1,12) < .6);
    % On compare "scoreB" et "scoreA", et on ajoute 1 à "n" si l'équipe B a
    % gagné.
    n = n + (scoreB > scoreA);
end
% On calcule l'intervalle de confiance à 2 sigmas pour la probabilité de
% victoire : "p" est l'estimateur de la probabilité de victoire, "sigma"
% celui de l'écart-type de l'inidcatrice dont on évalue l'espérance, "pinf"
% la borne inférieure de l'intervalle de confiance et "psup" sa borne
% supérieure.
p = n / N;
sigma = sqrt(p - p * p);
pinf = p - 2 * sigma / sqrt(N);
psup = p + 2 * sigma / sqrt(N);
% On affiche le résultat.
disp(['Probabilité de victoire de B pour q = ',num2str(q),' : entre ',...
    num2str(pinf),' et ',num2str(psup)]);
% Le programme s'arrête.
return
end
