%% Fonction principale
% La fonction "vingtetzero" évalue par la méthode de Monte-Carlo le gain
% moyen (pour une mise de 1) d'un joueur suivant la stratégie de base au
% jeu du vingt-et-zéro, avec un intervalle de confiance à 99 %.
function vingtetzero
% N est le nombre de simulations effectuées, ici 8 000.
N = 40000;
% S sera la somme des gains obtenus par le joueur, en vue de calculer le
% gain moyen.
S = 0;
% S2 sera la somme des carrés des gains obtenus par le joueur, en vue de
% calculer l'écart-type empirique.
S2 = 0;
% On lance la boucle de simulation principale.
for i = 1:N,
    % On simule une manche du joueur contre la banque. Cela est assuré par
    % la sous-routine "manche" (voir plus loin), qui renvoie le gain du
    % joueur.
    gain = manche;
    % On met à jour "S".
    S = S + gain;
    % On met à jour "S2".
    S2 = S2 + gain * gain;
end
% On calcule la moyenne empirique.
m = S / N;
% On calcule l'écart-type empirique.
sigma = sqrt(S2 / N - m * m);
% On calcule les bornes "mbas" et "mhaut" de l'intervalle de confiance.
mbas = m - 3.30 * sigma / sqrt(N);
mhaut = m + 3.30 * sigma / sqrt(N);
% On affiche le résultat.
disp(['Avec une certitude d''environ 99.9 %, le gain moyen pour le ',...
    'joueur est dans l''intervalle [',num2str(mbas),',',num2str(mhaut),...
    '].']);
% Le programme s'arrête.
return
end

%% Sous-routine "manche"
% La fonction "manche" simule une manche du joueur contre la banque et
% renvoie le gain "gain" du joueur.
function gain = manche
% On commence par tirer la première carte de la banque.
cartebanque = 1;
% En fonction de la carte affichée par la banque, le joueur choisit le
% seuil "stop" auquel il arrête de demander des cartes, selon la stratégie
% de base.
if cartebanque <= 3
    stop = 15;
elseif cartebanque <= 6
    stop = 14;
elseif cartebanque == 7
    stop = 15;
else
    stop = 16;
end
% Le joueur tire maintenant des cartes jusqu'à atteindre le seuil "stop".
% "totaljoueur" est le total des cartes du joueur.
totaljoueur = 0;
while(totaljoueur < stop)
    totaljoueur = totaljoueur + randi(10);
end
% Si le joueur a dépassé 20, il a perdu et le programme retourne un gain
% nul.
if totaljoueur > 20
    gain = 0;
    return
% C'est maintenant à la banque de tirer ses cartes.
else
    % "totalbanque" est le total des cartes de la banque ; rappelons que la
    % banque tire des cartes jusqu'à ce que ce total atteigne 17.
    totalbanque = cartebanque;
    while(totalbanque < 17)
        totalbanque = totalbanque + randi(10);
    end
% On regarde si la banque a dépassé le seuil de 20, auquel cas elle a perdu
% et le programme retourne un gain de 2.
    if totalbanque > 20
        gain = 2;
        return
    % On regarde maintenant si la banque a fait un meilleur score que le
    % joueur ou l'inverse ; le programme retournera 0 ou 2 selon le cas.
    elseif totalbanque > totaljoueur
        gain = 0;
        return
    elseif totaljoueur > totalbanque
        gain = 2;
        return
    % On traite pour finir les cas d'égalité : le programme retournera 1 ou
    % 2 selon que le total commun est respectivement 20 ou une autre
    % valeur.
    elseif totaljoueur == 20
        gain = 1;
        return
    else
        gain = 2;
        return
    end
end
end