%% Fonction principale
% La fonction "yahtzee" évalue par la méthode de Monte-Carlo la probabilité
% d'obtenir un yahtzee.
function yahtzee
% "N" note le nombre d'expériences choisi, ici 200000.
N = 200000;
% La variable "succes" comptera le nombre de fois qu'on a réussi à obtenir
% un yahtzee.
succes = 0;
% On lance une boucle de N essais, comptés par l'indice "i".
for i = 1:N,
    % On simule un essai du joueur. Cela est effectué par la sous-routine
    % "troislancers" (voir plus loin), qui renvoie 1 si le joueur a réussi
    % et 0 s'il a échoué. Le résultat est stocké dans "r" .
    r = troislancers;
    % On comptabilise le succès éventuel du joueur.
    succes = succes + r;
end
% On calcule l'estimateur "p" de la probabilité de succès.
p = succes / N;
% On affiche le résultat.
disp(['Estimateur de la probabilite de succès : ',num2str(p)]);
% Le programme s'arrête.
return
end

%% Sous-routine "troislancers"
% La fonction "troislancers" simule le comportement du joueur effectuant
% ses trois lancers en cherchant à obtenir un yahtzee. Elle renvoie 1 si
% l'essai se solde par un succès et 0 si c'est un échec.
function resultat = troislancers
% On simule le premier lancer. Le 5-uplet "des" représente les chiffres
% affichés par les cinq dés.
des = randi(6,[1,5]);
% On relance les dés une première fois. Cette étape est simulée par la
% sous-routine "relancer" (voir plus loin), qui renvoie le nouvel affichage
% des dés après ce lancer.
des = relancer(des);
% On relance les dés une seconde fois.
des = relancer(des);
% On teste si on a obtenu un yahtzee ou pas ; la réponse est stockée dans
% "resultat".
resultat = all(des == des(1));
% La fonction retourne "resultat".
return
end

%% Sous-routine "relancer"
% La fonction "relancer" simule le comportement du joueur relançant les dés
% et renvoie le nouvel affichage des dés. Elle prend en paramètre la liste
% des valeurs affichées.
function desrelances = relancer(des)
% On va regarder combien de fois chaque chiffre apparait. Les résultats
% seront stockés dans le 6-uplet "occurrences".
occurrences = zeros(1,6);
% On lance une boucle pour remplir la série "occurrences". La variable "i"
% indexe le dé qu'on est en train de regarder.
for i = 1:5,
    % On regarde la chiffre affiché par le i-ième dé et on incrémente
    % l'entrée correspondante de "occurrences".
    occurrences(des(i)) = occurrences(des(i)) + 1;
end
% On regarde le chiffre qui apparaît le plus souvent sur le plateau, qu'on
% appelle "recordman".
[~,recordman] = max(occurrences);
% On va maintenant donner la série des dés relancés, représentés par le
% 5-uplet "desrelances". On part de la situation des dés avant le relancer.
desrelances = des;
% On passe les dés en revue pour savoir s'ils sont à relancer ou pas. La
% variable "i" indexe le dé qu'on est en train de regarder.
for i = 1:5,
    % On relance le dé seulement si le chiffre qu'il affichait n'était pas
    % le recordman.
    if des(i) ~= recordman
        % On simule le relancer du dé.
        desrelances(i) = randi([1,6]);
    end
end
% La fonction retourne "desrelances".
return
end