%% Fonction principale
% La fonction "yahtzee_cond" améliore la fonction "yahtzee_spl" en
% utilisant la technique de conditionnement par rapport à la tribu B
% engendrée par les résultats des deux premiers lancers. L'interface avec
% l'utilisateur est la même que pour "yahtzee_spl". Je ne commente que les
% points qui diffèrent par rapport à la version naïve.
function yahtzee_cond(N)
% "S" et "S2" contiendront respectivement la somme et la somme des carrés
% des variables simulées. Notez que cette fois-ci on est bien obligé de
% comptabiliser séparément la somme et la somme des carrés, vu qu'il ne
% s'agit plus de simplement compter les occurrences d'un événement.
S = 0;
S2 = 0;
for i = 1:N,
    % La variable aléatoire dont on va évaluer l'espérance ici est la
    % probabilité conditionnelle d'obtenir un yahtzee à l'issue des deux
    % premiers lancers. Celle-ci, appelée "r", est simulée par la
    % sous-routine "deuxlancers", programmée plus bas.
    r = deuxlancers;
    % On met à jour "S" et "S2"
    S = S + r;
    S2 = S2 + r * r;
end
% On calcule l'espérance "p" et l'écart-type empirique "sigma" de la
% variable aléatoire r.
p = S / N;
sigma = sqrt(S2 / N - p * p);
erreur = 2 * sigma / sqrt(N);
disp(['Probabilite de succès : ',num2str(p),' ± ',num2str(erreur)]);
return
end

%% Sous-routine "deuxlancers"
% La fonction "deuxlancers" simule les deux premiers lancers d'un joueur
% cherchant à obtenir un yahtzee, et renvoie la probabilité conditionnelle
% de succès à l'issue de ces deux lancers.
function resultat = deuxlancers
des = randi(6,[1,5]);
des = relancer(des);
% On va regarder combien de fois chaque chiffre apparait. Les résultats
% seront stockés dans le 6-uplet "occurrences".
occurrences = zeros(1,6);
% On lance une boucle pour remplir la série "occurrences". La variable "i"
% indexe le dé qu'on est en train de regarder.
for i = 1:5,
    % On regarde la chiffre affiché par le i-ième dé et on incrémente
    % l'entrée correspondante de "occurrences".
    occurrences(des(i)) = occurrences(des(i)) + 1;
end
% Ce qui nous intéresse est de savoir quel est le nombre maximal
% d'occurrences d'un chiffre. Nous appelons "k" ce nombre.
k = max(occurrences);
% La probabilité conditionnelle à retourner est 1/6^{5-k}.
resultat = 6^(k-5);
return
end

%% Sous-routine "relancer"
% Cette sous-routine est inchangée par rapport à "yatzee_spl".
function desrelances = relancer(des)
occurrences = zeros(1,6);
for i = 1:5,
    occurrences(des(i)) = occurrences(des(i)) + 1;
end
[~,recordman] = max(occurrences);
desrelances = des;
for i = 1:5,
    if des(i) ~= recordman
        desrelances(i) = randi([1,6]);
    end
end
return
end

